@@ -102,7 +102,7 @@ void LockScreen::setHildonFlags()
 
     enable = 1;
     Atom winNTAtom = XInternAtom(QX11Info::display(), "_HILDON_WM_ACTION_NO_TRANSITIONS", false);
-    XChangeProperty(QX11Info::display(), m_View->winId(), winNTAtom, XA_INTEGER, 32, PropModeReplace, (uchar*) &enable, 1);
+    XChangeProperty(QX11Info::display(), m_View->winId(), winNTAtom, XA_CARDINAL, 32, PropModeReplace, (uchar*) &enable, 1);
 
 #endif
 }
