@@ -56,10 +56,8 @@ void LsMediaMetadata::applySettings()
     m_TitleColor = getColorSetting("TitleColor", QColor(255,255,255));
     m_ArtistColor = getColorSetting("ArtistColor", QColor(255,255,255));
 
-    m_TitleFont = QFont();
-    m_TitleFont.setPointSize(getSetting("TitleFontSize", 20).toInt());
-    m_ArtistFont = QFont();
-    m_ArtistFont.setPointSize(getSetting("ArtistFontSize", 15).toInt());
+    m_TitleFont = getFontSetting("TitleFont", QFont("", 20, QFont::Normal, false));
+    m_ArtistFont = getFontSetting("ArtistFont", QFont("", 14, QFont::Normal, false));
 
     setSizeAndPosition(QSize(100, 100), QPoint(0, 0));
 }
